%%% Script to make stacked barplots to show variance components %%%

%% Preps
% Directories
rootdir    =    pwd;
datadir    =    fullfile(rootdir,'data');
fitdir     =    fullfile(rootdir,'fits');
figuredir  =    fullfile(rootdir,'figures/EM/WO/Rein_Sens');

%% Get estimates from winning model for all estimation methods
% Load data
    %separate
    load(fullfile(fitdir,'best_fitted_modelsEM_reinsens_WO_multiitonesession1.mat'))
    models1_RS=models;
    load(fullfile(fitdir,'best_fitted_modelsEM_reinsens_WO_multiitonesession2.mat'))
    models2_RS=models;
    % joint
    load(fullfile(fitdir,'best_fitted_modelsEM_reinsens_WO_multiit.mat'))
    models_RS=models;

subfolder='lld2be'; n=6;   x=[1,2,3,NaN,NaN]; y=[1 3;2 4;5 6; NaN NaN;NaN NaN];
for i=1:3
    if i==1
        beta1_s(:,:,i)=[models1_RS(n).stats.EML(x(1),:).',models2_RS(n).stats.EML(x(1),:).'];
        beta1(:,:,i)=[models_RS(n).stats.EML(y(1,1),:).',models_RS(n).stats.EML(y(1,2),:).'];
        beta2_s(:,:,i)=[models1_RS(n).stats.EML(x(2),:).',models2_RS(n).stats.EML(x(2),:).'];
        beta2(:,:,i)=[models_RS(n).stats.EML(y(2,1),:).',models_RS(n).stats.EML(y(2,2),:).'];
        alpha_s(:,:,i)=[models1_RS(n).stats.EML(x(3),:).',models2_RS(n).stats.EML(x(3),:).'];
        alpha(:,:,i)=[models_RS(n).stats.EML(y(3,1),:).',models_RS(n).stats.EML(y(3,2),:).'];
        
    elseif i==2
        beta1_s(:,:,i)=[models1_RS(n).stats.EMAP0(x(1),:).',models2_RS(n).stats.EMAP0(x(1),:).'];
        beta1(:,:,i)=[models_RS(n).stats.EMAP0(y(1,1),:).',models_RS(n).stats.EMAP0(y(1,2),:).'];
        beta2_s(:,:,i)=[models1_RS(n).stats.EMAP0(x(2),:).',models2_RS(n).stats.EMAP0(x(2),:).'];
        beta2(:,:,i)=[models_RS(n).stats.EMAP0(y(2,1),:).',models_RS(n).stats.EMAP0(y(2,2),:).'];
        alpha_s(:,:,i)=[models1_RS(n).stats.EMAP0(x(3),:).',models2_RS(n).stats.EMAP0(x(3),:).'];
        alpha(:,:,i)=[models_RS(n).stats.EMAP0(y(3,1),:).',models_RS(n).stats.EMAP0(y(3,2),:).'];
    else
        beta1_s(:,:,i)=[models1_RS(n).E(x(1),:).',models2_RS(n).E(x(1),:).'];
        beta1(:,:,i)=[models_RS(n).E(y(1,1),:).',models_RS(n).E(y(1,2),:).'];
        beta2_s(:,:,i)=[models1_RS(n).E(x(2),:).',models2_RS(n).E(x(2),:).'];
        beta2(:,:,i)=[models_RS(n).E(y(2,1),:).',models_RS(n).E(y(2,2),:).'];
        alpha_s(:,:,i)=[models1_RS(n).E(x(3),:).',models2_RS(n).E(x(3),:).'];
        alpha(:,:,i)=[models_RS(n).E(y(3,1),:).',models_RS(n).E(y(3,2),:).'];
    end
end

paramnames={'beta1_s','beta1','beta2_s','beta2' ,'alpha_s', 'alpha'};
% For reference: formula for ICC(A,1)
%r = (MSR - MSE) / (MSR + (k-1)*MSE + k*(MSC-MSE)/n);  

%% Run bootstrap
samples = [10,20,30,40,50,75,100,125,150,200,250,300];
absval = [];
relval = [];
for j=1:length(paramnames)
    for iter=1:1000
        disp(strcat('Parameter: ', string(j), ', Iteration: ', string(iter)))
        for sample=1:length(samples)
            tmp = datasample(eval(string(paramnames(j))),samples(sample),1);
            for i=1:3
                M(:,:,i)=eval(strcat('tmp(:,:,', num2str(i),')'));
                [n, k] = size(M(:,:,i));
                SStotal = nanvar(vertcat(M(:,1,i), M(:,2,i))) *(n*k - 1);
                MSR(i) = nanvar(mean(M(:,:,i), 2)) * k;                        % Between subs variance
                MSW(i) = nansum(var(M(:,:,i),0, 2)) / n;                       % Within subs variance
                MSC(i) = nanvar(mean(M(:,:,i), 1)) * n;                        % Session variance
                MSE(i) = (SStotal - MSR(i) *(n - 1) - MSC(i) * (k -1))/ ((n - 1) * (k - 1));     %Errror variance
            end
            x=sum([MSR', MSE', MSC'],2);
            absval = [absval; repmat(j,3,1), repmat(iter,3,1), repmat(samples(sample),3,1), [1;2;3], MSR'./1, MSE'./1, MSC'./1];
            relval = [relval; repmat(j,3,1), repmat(iter,3,1), repmat(samples(sample),3,1), [1;2;3], MSR'./x, MSE'./x, MSC'./x];
            clear M
        end
    end
end
abs_table = array2table(absval, 'VariableNames', {'variable','iteration','n','model','between','error','within'});
rel_table = array2table(relval, 'VariableNames', {'variable','iteration','n','model','between','error','within'});
writetable(abs_table,'../../absolute_variance_bootstrap.csv');
writetable(rel_table,'../../relative_variance_bootstrap.csv');