library(TOSTER)
library(reshape2)
library(tidyverse)
library(ggplot2)
library(dplyr)
library(data.table)


# Load data for each n in our dataset
boot10 <- read.csv("bootstrap_n-10_iterations-1000.csv")
boot20 <- read.csv("bootstrap_n-20_iterations-1000.csv")
boot30 <- read.csv("bootstrap_n-30_iterations-1000.csv")
boot40 <- read.csv("bootstrap_n-40_iterations-1000.csv")
boot50 <- read.csv("bootstrap_n-50_iterations-1000.csv")
boot75 <- read.csv("bootstrap_n-75_iterations-1000.csv")
boot100 <- read.csv("bootstrap_n-100_iterations-1000.csv")
boot125 <- read.csv("bootstrap_n-125_iterations-1000.csv")
boot150 <- read.csv("bootstrap_n-150_iterations-1000.csv")
boot200 <- read.csv("bootstrap_n-200_iterations-1000.csv")
boot250 <- read.csv("bootstrap_n-250_iterations-1000.csv")
boot300 <- read.csv("bootstrap_n-300_iterations-1000.csv")
boot_williams <- rbind(boot10, boot20, boot30, boot40, boot50, boot75, boot100, boot125, boot150, boot200, boot250, boot300)
boot_williams$dataset <- 1

# Load data for each n in the waltmann dataset
boot10 <- read.csv("bootstrap_n-10_iterations-1000_Waltmann.csv")
boot20 <- read.csv("bootstrap_n-20_iterations-1000_Waltmann.csv")
boot30 <- read.csv("bootstrap_n-30_iterations-1000_Waltmann.csv")
boot40 <- read.csv("bootstrap_n-40_iterations-1000_Waltmann.csv")
boot50 <- read.csv("bootstrap_n-50_iterations-1000_Waltmann.csv")
boot75 <- read.csv("bootstrap_n-75_iterations-1000_Waltmann.csv")
boot100 <- read.csv("bootstrap_n-100_iterations-1000_Waltmann.csv")
boot125 <- read.csv("bootstrap_n-125_iterations-1000_Waltmann.csv")
boot150 <- read.csv("bootstrap_n-150_iterations-1000_Waltmann.csv")
boot200 <- read.csv("bootstrap_n-200_iterations-1000_Waltmann.csv")
boot250 <- read.csv("bootstrap_n-250_iterations-1000_Waltmann.csv")
boot300 <- read.csv("bootstrap_n-300_iterations-1000_Waltmann.csv")
boot_waltmann <- rbind(boot10, boot20, boot30, boot40, boot50, boot75, boot100, boot125, boot150, boot200, boot250, boot300)
boot_waltmann$dataset <- 2

boot <- rbind(boot_williams, boot_waltmann)

# Set names for labelling figures
variable_names <- c("∆ reaction times", "Accuracy", "Perseveration", 
                    "Reaction times after losses", "Reaction times after wins", 
                    "Reaction times overall", "Stay behaviour overall", 
                    "Staying after losses", "Staying after wins")
model_names <- c("Mean", "Separate", "Joint", "Model Calculated")
variance_names <- c("Within-subject", "Error", "Between-subject")
list <- lapply(1:length(variance_names), function(i){
  variance_names[i]
  list <- lapply(1:length(variable_names), function(ii){
    subdata <- subset(boot, variable == ii & varcomp == i & model != 4)
    # set columns as factors
    factors <- c("n","model","dataset")
    subdata[factors] <- lapply(subdata[factors], factor)
    tmp <- aov(value ~ n * model * dataset, data = subdata)
    variable_names[ii]
    equ_anova(tmp, 0.06)
  })
  names(list) <- variable_names
  data.table::rbindlist(list, idcol ="variable")
})
names(list) <- variance_names
anovas_df <- data.table::rbindlist(list, idcol ="variance")
anovas_df$equiv_sign <- case_when(anovas_df$p.null < 0.05 & anovas_df$p.equ < 0.05 ~ "~",
                                  anovas_df$p.null >= 0.05 & anovas_df$p.equ < 0.05 ~ "=",
                                  anovas_df$p.null < 0.05 & anovas_df$p.equ >= 0.05 ~ sprintf("\u2731"),
                                  anovas_df$p.null >= 0.05 & anovas_df$p.equ >= 0.05 ~ "?")
anovas_df$variance <- factor(anovas_df$variance, levels = variance_names, labels = c("Within-subject","Between-subject","Error"))
anovas_df$effect <- factor(anovas_df$effect, levels = unique(anovas_df$effect), labels = c("Sample size","Estimation method","Dataset",str_interp('Sample size ${sprintf("\u2731")} Estimaton method'), str_interp('Sample size ${sprintf("\u2731")} Dataset'), str_interp('Model ${sprintf("\u2731")} Dataset'), str_interp('Sample size ${sprintf("\u2731")} Estimation method ${sprintf("\u2731")} Dataset')))


ggplot(anovas_df, aes(x=effect, y=variable, fill=pes)) +
  geom_raster() +
  geom_text(aes(label = equiv_sign), colour = "white", size = 6, fontface = "bold") +
  scale_fill_viridis_c(name = "Effect size") +
  facet_wrap("variance") +
  theme_minimal() +
  theme(text = element_text(size = 20), axis.title = element_blank()) +
  theme(legend.title = element_text(size = 16)) +
  theme(axis.text.x = element_text(angle = 270, hjust=0))
ggsave("behavioural-anova-overview_figure.png", bg = "white", height = 14, width=15)
