# Load packages
library(ggplot2)
library(ggridges)
library(RColorBrewer)
library(ggpubr)
library(tidyverse)

# Load data for each n
boot10 <- read.csv("bootstrap_n-10_iterations-1000.csv")
boot20 <- read.csv("bootstrap_n-20_iterations-1000.csv")
boot30 <- read.csv("bootstrap_n-30_iterations-1000.csv")
boot40 <- read.csv("bootstrap_n-40_iterations-1000.csv")
boot50 <- read.csv("bootstrap_n-50_iterations-1000.csv")
boot75 <- read.csv("bootstrap_n-75_iterations-1000.csv")
boot100 <- read.csv("bootstrap_n-100_iterations-1000.csv")
boot125 <- read.csv("bootstrap_n-125_iterations-1000.csv")
boot150 <- read.csv("bootstrap_n-150_iterations-1000.csv")
boot200 <- read.csv("bootstrap_n-200_iterations-1000.csv")
boot250 <- read.csv("bootstrap_n-250_iterations-1000.csv")
boot300 <- read.csv("bootstrap_n-300_iterations-1000.csv")
boot <- rbind(boot10, boot20, boot30, boot40, boot50, boot75, boot100, boot125, boot150, boot200, boot250, boot300)

# Set names for labelling figures
variable_names <- c("∆ reaction times", "Accuracy", "Perseveration", 
                    "Reaction times after losses", "Reaction times after wins", 
                    "Reaction times overall", "Stay behaviour overall", 
                    "Staying after losses", "Staying after wins")
model_names <- c("Mean", "Separate", "Joint", "Model Calculated")
variance_names <- c("Within-subject", "Error", "Between-subject")
image_order <- c(2,3,7,9,8,6,5,4,1)

for (i in 1:length(variance_names)) { # variance components
  for (ii in 1:length(model_names)) { # models
    plots <- list()
    for (iii in 1:length(image_order)) { # parameters
      subdata <- subset(boot, varcomp == i & model == ii & variable == image_order[iii])
      old_n <- unique(subdata$n)
      new_n <- 1:length(old_n)
      subdata$n[subdata$n %in% old_n] <- new_n[match(subdata$n, old_n)]
      plot <- ggplot(subdata, aes(x = n, y = value)) +
        geom_point() +
        stat_density_2d(geom = "raster", aes(fill = after_stat(density)), contour = FALSE, alpha = 0.9) +
        scale_fill_distiller(palette=4, direction=1) +
        scale_x_continuous(limits = c(0.8, 12.2), expand = c(0, 0), labels = old_n, breaks = new_n) +
        scale_y_continuous(limits = c(-0.02, 1.02), expand = c(0, 0)) +
        theme(legend.position='none', panel.background = element_blank()) + 
        labs(title = variable_names[image_order[iii]], x = "Number of participants", y = "Variance proportion")
      plots[[iii]] <- plot
    }
    variable_plot <- ggarrange(plotlist = plots, nrow = 3, ncol = 3)
    variable_plot <- annotate_figure(variable_plot, top = text_grob(str_interp("${variance_names[i]} variance - ${model_names[ii]} model"), face = "bold", size = 24))
    ggsave(str_interp("${variance_names[i]}_${model_names[ii]}_figure.png"), variable_plot, width = 10.5, height = 10.5, bg = "white")
  }
}

### POSSIBLE FUTURE WORK ###
# https://stackoverflow.com/questions/24078774/overlay-two-ggplot2-stat-density2d-plots-with-alpha-channels
# THIS STACK OVERFLOW LINK SHOWS HOW TO PLOT TWO 2D DENSITIES ON ONE GRAPH
# THIS COULD BE USED TO SHOW WITHIN AND BETWEEN SUBJECT VARIANCE ON THE SAME AXIS
# CURRENTLY THE BELOW CODE DOESN'T WORK. I'M NOT SURE HOW TO FIX THIS

#subdata <- subset(boot, variable == i & model == 3)
#old_n <- unique(subdata$n)
#new_n <- 1:length(old_n)
#subdata$n[subdata$n %in% old_n] <- new_n[match(subdata$n, old_n)]
#ggplot(rbind(subset(subdata, varcomp == 1), subset(subdata, varcomp == 3)), aes(x = n, y = value)) +
#  geom_point() +
#  stat_density2d(geom="tile", aes(fill = varcomp, alpha=..density..), contour=FALSE) + 
#  scale_fill_manual(values=c("1"="#FF0000", "2"="#00FF00"))
### ANOVA ###
#library(rstatix)
#library(TOSTER)
#for (i in 1:length(variable_names)) {
#  subdata <- subset(boot, variable == i & model != 4)
#  tmp <- aov(value ~ varcomp * n * model, data = subdata)
#  print(summary(tmp))
#  print(equ_anova(tmp, 0.1))
#  print(variable_names[i])
#}
