# Load packages
library(ggplot2)
library(ggridges)
library(RColorBrewer)
library(ggpubr)
library(tidyverse)


# Load data for each n
boot <- read.csv("relative_variance_bootstrap.csv")

#melt from wide to long
boot <- melt(setDT(boot), id.vars = c("variable","iteration","n","model"), variable.name = "varcomp")
boot$varcomp <- fct_rev(boot$varcomp) # reverse factor to be in line with other figures
# Set names for labelling figures
variable_names <- c("Reinforcement sensitivity for wins: separate estimation",
                    "Reinforcement sensitivity for wins: joint estimation",
                    "Reinforcement sensitivity for losses: separate estimation",
                    "Reinforcement sensitivity for losses: joint estimation",
                    "Learning rate: separate estimation",
                    "Learning rate: joint estimation")
variable_names_savefile <- c("beta1_s", "beta_1", "beta2_s","beta2", "alpha_s", "alpha")
model_names <- c("ML", "MAP0", "EM")
variance_names <- c("between", "error", "within")
variance_names_plots <- c("Between-subject variance", "Error variance", "Within-subject variance")

for (x in 1:length(variance_names)) { # iterate over variance types
  variable_plots <- list()
  for (i in 1:length(variable_names)) { # variable names
    model_plots <- list()
    for (ii in 1:length(model_names)) { # model fitting approaches
      print(c(variable_names[i], model_names[ii], variance_names[x]))
      subdata <- subset(boot, varcomp == variance_names[x] & model == ii & variable == i)
      old_n <- unique(subdata$n)
      new_n <- 1:length(old_n)
      subdata$n[subdata$n %in% old_n] <- new_n[match(subdata$n, old_n)]
      plot <- ggplot(subdata, aes(x = n, y = value)) +
        geom_point() +
        stat_density_2d(geom = "raster", aes(fill = after_stat(density)), contour = FALSE, alpha = 0.9) +
        scale_fill_distiller(palette=4, direction=1) +
        scale_x_continuous(limits = c(0.8, 12.2), expand = c(0, 0), labels = old_n, breaks = new_n) +
        scale_y_continuous(limits = c(-0.02, 1.02), expand = c(0, 0)) +
        theme(legend.position='none', panel.background = element_blank()) + 
        labs(title = model_names[ii], x = "Number of participants", y = "Variance proportion")
      model_plots[[ii]] <- plot
      
      
    }
    variable_plot <- ggarrange(plotlist = model_plots, nrow = 1, ncol = 3)
    variable_plot <- annotate_figure(variable_plot, top = text_grob(variable_names[i], face = "bold", size = 18))
    variable_plots[[i]] <- variable_plot
  }
  variance_plot <- ggarrange(plotlist = variable_plots, nrow = 3, ncol = 2)
  variance_plot <- annotate_figure(variance_plot, top = text_grob(variance_names_plots[x], face = "bold", size = 24))
  ggsave(str_interp("model_parameters_${variance_names[x]}-variance_bootstrap_plot.png"), variance_plot, width = 21, height = 10.5, bg = "white")
}


### POSSIBLE FUTURE WORK ###
# https://stackoverflow.com/questions/24078774/overlay-two-ggplot2-stat-density2d-plots-with-alpha-channels
# THIS STACK OVERFLOW LINK SHOWS HOW TO PLOT TWO 2D DENSITIES ON ONE GRAPH
# THIS COULD BE USED TO SHOW WITHIN AND BETWEEN SUBJECT VARIANCE ON THE SAME AXIS
# CURRENTLY THE BELOW CODE DOESN'T WORK. I'M NOT SURE HOW TO FIX THIS

#subdata <- subset(boot, variable == i & model == 3)
#old_n <- unique(subdata$n)
#new_n <- 1:length(old_n)
#subdata$n[subdata$n %in% old_n] <- new_n[match(subdata$n, old_n)]
#ggplot(rbind(subset(subdata, varcomp == 1), subset(subdata, varcomp == 3)), aes(x = n, y = value)) +
#  geom_point() +
#  stat_density2d(geom="tile", aes(fill = varcomp, alpha=..density..), contour=FALSE) + 
#  scale_fill_manual(values=c("1"="#FF0000", "2"="#00FF00"))
### ANOVA ###
#library(rstatix)
#library(TOSTER)
#for (i in 1:length(variable_names)) {
#  subdata <- subset(boot, variable == i & model != 4)
#  tmp <- aov(value ~ varcomp * n * model, data = subdata)
#  print(summary(tmp))
#  print(equ_anova(tmp, 0.1))
#  print(variable_names[i])
#}
